<?php

class ArrayPieceSquadro implements ArrayAccess, Countable {
    private $pieces = [];

    public function offsetExists($offset) {
        return isset($this->pieces[$offset]);
    }

    public function offsetGet($offset) {
        return $this->pieces[$offset];
    }

    public function offsetSet($offset, $value) {
        if ($value instanceof PieceSquadro) {
            $this->pieces[$offset] = $value;
        }
    }

    public function offsetUnset($offset) {
        unset($this->pieces[$offset]);
    }

    public function count() {
        return count($this->pieces);
    }

    public function add(PieceSquadro $piece) {
        $this->pieces[] = $piece;
    }

    public function remove($index) {
        if (isset($this->pieces[$index])) {
            unset($this->pieces[$index]);
        }
    }

    public function toJson() {
        return json_encode(array_map(function($piece) {
            return $piece->toJson();
        }, $this->pieces));
    }

    public static function fromJson($json) {
        $data = json_decode($json, true);
        $array = new self();
        foreach ($data as $pieceJson) {
            $array->add(PieceSquadro::fromJson($pieceJson));
        }
        return $array;
    }
}
?>
